@@ -5,7 +5,7 @@
    driver classes/backends. All virtual functions have to be implemented by
    the specific driver class. See drvSAMPL.cpp
   
-   Copyright (C) 1993 - 2009 Wolfgang Glunz, wglunz35_AT_pstoedit.net
+   Copyright (C) 1993 - 2013 Wolfgang Glunz, wglunz35_AT_pstoedit.net
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -83,6 +83,9 @@ public:
 	bool operator==(const Point & p2) const { 
 		return (x_ == p2.x_) && (y_ == p2.y_); //lint !e777
 	}
+	bool operator!=(const Point & p2) const { 
+		return !(*this == p2);
+	}
 	Point operator+(const Point & p) const { return Point (x_+p.x_,y_+p.y_); }
 	const Point & operator+=(const Point & p) { x_+=p.x_; y_+=p.y_; return *this; }
 	Point operator*(float f) const { return Point (x_*f,y_*f); }
@@ -160,6 +163,7 @@ public:
 		RSString	glyphnames;
 		bool		is_non_standard_font;
 		RSString    currentFontName;
+		RSString    currentFontUnmappedName;
 		RSString    currentFontFamilyName;
 		RSString    currentFontFullName;
 		RSString    currentFontWeight;
@@ -320,7 +324,7 @@ public:
 
 	static bool Verbose();  // need a wrapper function because static initialized data cannot be DLLEXPORTed
 	static void SetVerbose(bool param);
-	static unsigned int totalNumberOfPages;
+	static unsigned int &totalNumberOfPages();
 	
 	static BBox	* bboxes() ; // [maxPages]; // array of bboxes - maxpages long
 	static RSString& pstoeditHomeDir(); // usually the place where the binary is installed
@@ -338,7 +342,7 @@ protected:
 	RSString       	outBaseName; 	// just the basename (no path, no suffix)
 	unsigned int	d_argc;
 	const char **			d_argv; // array of driver argument strings
-	const class PsToEditOptions & globaloptions; 
+	class PsToEditOptions & globaloptions; /* non const because driver can also add an option during ctor */
 	float           currentDeviceHeight; // normally 792 pt (US Letter); used for flipping y values.
 	float           currentDeviceWidth;  
 	float           x_offset;
@@ -381,7 +385,7 @@ public:
 		ostream & theerrStream,		
 		const char* nameOfInputFile_p,
 		const char* nameOfOutputFile_p,
-		const PsToEditOptions & globaloptions_p,
+		PsToEditOptions & globaloptions_p,
 		const DriverDescription * Pdriverdesc_p
 	); // constructor
 	virtual ~drvbase();  		// destructor
@@ -828,7 +832,7 @@ typedef drawingelement<(unsigned int) 3,curveto> 	Curveto;
 	       ostream & theerrStream, 			\
 		   const char* nameOfInputFile_p,	\
 	       const char* nameOfOutputFile_p,	\
-		   const PsToEditOptions & globaloptions_p,		\
+		   PsToEditOptions & globaloptions_p, /* non const because driver can also add options */ 		\
 		   const DriverDescription * descptr)	
 
 #define constructBase drvbase(driveroptions_p,theoutStream,theerrStream,nameOfInputFile_p,nameOfOutputFile_p,globaloptions_p,descptr), options((DriverOptions*)DOptions_ptr)
@@ -943,18 +947,19 @@ public:
 			 ostream & theerrStream,   
 			 const char* const nameOfInputFile,
 		     const char* const nameOfOutputFile,
-			 const PsToEditOptions & globaloptions_p
+			 PsToEditOptions & globaloptions_p
 			 ) const = 0;
 	virtual ProgramOptions * createDriverOptions() const = 0;
 
 	virtual unsigned int getdrvbaseVersion() const { return 0; } // this is only needed for the driverless backends (ps/dump/gs)
 
+	const char * additionalInfo() const;
  // Data members
 	const char * const symbolicname;
 	const char * const short_explanation;
 	const char * const long_explanation;
 	const char * const suffix;
-	const char * const additionalInfo;
+
 	const bool 	backendSupportsSubPathes;
 	const bool 	backendSupportsCurveto;
 	const bool 	backendSupportsMerging; // merge a separate outline and filling of a polygon -> 1. element
@@ -964,7 +969,13 @@ public:
 	const bool	backendSupportsMultiplePages;
 	const bool	backendSupportsClipping;
 	const bool	nativedriver;
-	RSString filename; // where this driver is loaded from
+	RSString filename; 
+	// where this driver is loaded from
+	// Note: formerly this was a RSString - but that caused problems under X64 / Windows
+	// it seems as constructing and deleting heap during start-up phase when not all DLLs are fully initialized
+	// can cause these problems (well - I know then order of init among DLLs/SOs is not guaranteed by C++)
+	// But the passed strings are temporary - so we need to take a copy to the heap (without destroying it later -> small leak)
+
 	const checkfuncptr checkfunc;
 
 	static const char * currentfilename; // the name of the file from which the plugin is loaded
@@ -1009,13 +1020,13 @@ public:
 			checkfunc_p
 			)
 		{}
-	drvbase * CreateBackend (
+	virtual drvbase * CreateBackend (
 			const char * const driveroptions_P,
 		    ostream & theoutStream, 
 		    ostream & theerrStream,   
 			const char* const nameOfInputFile,
 	       	const char* const nameOfOutputFile,
-			const PsToEditOptions & globaloptions_p
+			PsToEditOptions & globaloptions_p /* non const because driver can also add arguments */
 			 ) const
 	{ 
 		drvbase * backend = new T(driveroptions_P, theoutStream, theerrStream,nameOfInputFile,nameOfOutputFile, globaloptions_p,this); 
