@@ -38,7 +38,8 @@ class drvplot : public drvbase
 	public:
 		OptionT < RSString, RSStringValueExtractor> type;
 		DriverOptions():
-			type(true,"plotformat","string",0,"plotutil format to generate",0,(const char *)"meta")
+			ProgramOptions(true), // expect unhandled options
+			type(true,"-plotformat","string",0,"plotutil format to generate",0,(const char *)"meta")
 	// pagesize(true,"-pagesize","string",0,"page size, e.g. a4",0,)
 		{
 			ADD(type);
